<?php
/**
 * Template part for displaying front page about.
 *
 * @package Moral
 */
// Get default  mods value.
$default = franchise_get_default_mods();

// Get the content type.
$about = get_theme_mod( 'franchise_about', 'page' );

// Bail if the section is disabled.
if ( 'disable' === $about ) {
	return;
}

// Query if the content type is either post or page.

$id = get_theme_mod( 'franchise_about_page' );

$query = new WP_Query( array( 'post_type' => 'page', 'p' => absint( $id ) ) );

if ( $query->have_posts() ) {
	while ( $query->have_posts() ) {
		$query->the_post();
		$img_url     = get_the_post_thumbnail_url( $id, 'large' );
		$title   = get_the_title();
		$content = get_the_excerpt();
		$btn_url     = get_permalink();
	}
	wp_reset_postdata();
}

// Get the common settings value  in custom, page and post.
$sub_title   = get_theme_mod( 'franchise_about_sub_title', $default['franchise_about_sub_title'] );

?>

<div id="about-us" class="relative page-section">
    <div class="wrapper">
    	<?php 
    	$class = ( ! empty( $img_url ) ) ? 'has-featured-image' : '' ;
    	?>
        <article class="<?php echo esc_attr( $class ); ?>">
            <div class="entry-container">
                <header class="entry-header">
                    <span class="section-subtitle"><?php echo esc_html( $sub_title ); ?></span>
                    <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
                </header>

                <?php if( ! empty( $img_url ) ) : ?>
	                <div class="featured-image hidden small" style="background-image: url('<?php echo esc_url( $img_url );?>');">
	                    <a class="featured-image-link" href="<?php echo esc_url( $btn_url ); ?>"></a>
	                </div><!-- .featured-image -->
            	<?php endif; ?>

                <div class="entry-content">
                    <?php echo wp_kses_post( $content ); ?>
                </div><!-- .entry-content -->

                <div class="more-link">
                    <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-primary"><?php esc_html_e( 'Know More', 'franchise' ); ?></a>
                </div><!-- .more-link -->
            </div><!-- .entry-container -->

            <?php if( ! empty( $img_url ) ) : ?>
	            <div class="featured-image hidden large" style="background-image: url('<?php echo esc_url( $img_url );?>');">
	                <a class="featured-image-link" href="<?php echo esc_url( $btn_url ); ?>"></a>
	            </div><!-- .featured-image -->
        	<?php endif; ?>
        </article>
    </div><!-- .wrapper -->
</div><!-- #about-us -->