<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 */

/**
 * Get all the default values of the theme mods.
 */
function franchise_get_default_mods() {
	$franchise_default_mods = array(
		// About
		'franchise_about_sub_title' => esc_html__( 'Who we are', 'franchise' ),
		
		// Projects
		'franchise_projects_title' => esc_html__( 'Our Projects', 'franchise' ),
		'franchise_projects_sub_title' => esc_html__( 'Buy things. Get happy.', 'franchise' ),

		// Services
		'franchise_services_custom_sub_title' => esc_html__( '01 Service', 'franchise' ),
		
		// Testimonials
		'franchise_testimonial_custom_sub_title' => esc_html__( 'New York, U.S.A', 'franchise' ),

		// Blog section
		'franchise_blog_section_title' => esc_html__( 'Stay Updated. Happening Now.', 'franchise' ),
		'franchise_blog_section_sub_title' => esc_html__( 'Latest Blog', 'franchise' ),

	);

	return apply_filters( 'franchise_default_mods', $franchise_default_mods );
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function franchise_customize_register( $wp_customize ) {
	/**
	 * Separator custom control
	 *
	 * @version 1.0.0
	 * @since  1.0.0
	 */
	class Franchise_Separator_Custom_Control extends WP_Customize_Control {
		/**
		 * Control type
		 *
		 * @var string
		 */
		public $type = 'franchise-separator';
		/**
		 * Control method
		 *
		 * @since 1.0.0
		 */
		public function render_content() {
			?>
			<p><hr style="border-color: #222; opacity: 0.2;"></p>
			<?php
		}
	}

	$default = franchise_get_default_mods();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'franchise_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'franchise_customize_partial_blogdescription',
		) );
	}

	/**
	 *
	 * 
	 * Header panel
	 *
	 * 
	 */
	// Header panel
	$wp_customize->add_panel(
		'franchise_header_panel',
		array(
			'title' => esc_html__( 'Header', 'franchise' ),
			'priority' => 100
		)
	);

	$wp_customize->get_section( 'title_tagline' )->panel         = 'franchise_header_panel';

	// Header text display setting
	$wp_customize->add_setting(	
		'franchise_header_text_display',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_header_text_display',
		array(
			'section'		=> 'title_tagline',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Display Site Title and Tagline', 'franchise' ),
		)
	);

	// Header section
	$wp_customize->add_section(
		'franchise_header_section',
		array(
			'title' => esc_html__( 'Header', 'franchise' ),
			'panel' => 'franchise_header_panel',
		)
	);

	// Header search form settings
	$wp_customize->add_setting(
		'franchise_show_search',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'franchise_show_search',
		array(
			'section'		=> 'franchise_header_section',
			'label'			=> esc_html__( 'Show search.', 'franchise' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 *
	 * 
	 * Home sections panel
	 *
	 * 
	 */
	// Home sections panel
	$wp_customize->add_panel(
		'franchise_home_panel',
		array(
			'title' => esc_html__( 'Homepage', 'franchise' ),
			'priority' => 105
		)
	);

	$wp_customize->get_section( 'static_front_page' )->panel         = 'franchise_home_panel';

	// Your latest posts title setting
	$wp_customize->add_setting(	
		'franchise_your_latest_posts_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_your_latest_posts_title',
		array(
			'section'		=> 'static_front_page',
			'label'			=> esc_html__( 'Title:', 'franchise' ),
			'active_callback' => 'franchise_is_latest_posts',
			'input_attrs' => array(
			    'placeholder' => esc_html__( 'Blogs', 'franchise' ),
			)
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_your_latest_posts_title', 
		array(
	        'selector'            => '.home.blog #page-header .page-title',
			'render_callback'     => 'franchise_your_latest_posts_partial_title',
    	) 
    );

	/**
	 * Slider section
	 */
	// Slider section
	$wp_customize->add_section(
		'franchise_slider',
		array(
			'title' => esc_html__( 'Slider', 'franchise' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Slider enable settings
	$wp_customize->add_setting(
		'franchise_slider',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'page'
		)
	);

	$wp_customize->add_control(
		'franchise_slider',
		array(
			'section'		=> 'franchise_slider',
			'label'			=> esc_html__( 'Content type:', 'franchise' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise' ),
					'page' => esc_html__( 'Page', 'franchise' ),
			 	)
		)
	);

	for ( $i=1; $i <= 2; $i++ ) { 
		// Slider page setting
		$wp_customize->add_setting(
			'franchise_slider_page_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'franchise_slider_page_' . $i,
			array(
				'section'		=> 'franchise_slider',
				'label'			=> esc_html__( 'Page ', 'franchise' ) . $i,
				'type'			=> 'dropdown-pages',
				'active_callback' => 'franchise_if_slider_not_disabled'
			)
		);
	}

	/**
	 * About section
	 */
	// About section
	$wp_customize->add_section(
		'franchise_about',
		array(
			'title' => esc_html__( 'About', 'franchise' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// About enable settings
	$wp_customize->add_setting(
		'franchise_about',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'page'
		)
	);

	$wp_customize->add_control(
		'franchise_about',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Content type:', 'franchise' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise' ),
					'page' => esc_html__( 'Page', 'franchise' ),
			 	)
		)
	);

	// About page setting
	$wp_customize->add_setting(
		'franchise_about_page',
		array(
			'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'franchise_about_page',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Page:', 'franchise' ),
			'type'			=> 'dropdown-pages',
			'active_callback' => 'franchise_if_about_enabled'
		)
	);

	// About sub title setting
	$wp_customize->add_setting(
		'franchise_about_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_about_sub_title',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Sub title:', 'franchise' ),
			'active_callback' => 'franchise_if_about_enabled',
			'input_attrs' => array(
			    'placeholder' => $default['franchise_about_sub_title'],
			)
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_about_sub_title', 
		array(
	        'selector'            => '#about-us .section-subtitle',
			'render_callback'     => 'franchise_about_partial_sub_title',
    	) 
    );

	/**
	 * Services section
	 */
	// Services section
	$wp_customize->add_section(
		'franchise_services',
		array(
			'title' => esc_html__( 'Services', 'franchise' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Services enable settings
	$wp_customize->add_setting(
		'franchise_services',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'post'
		)
	);

	$wp_customize->add_control(
		'franchise_services',
		array(
			'section'		=> 'franchise_services',
			'label'			=> esc_html__( 'Content type:', 'franchise' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise' ),
					'post' => esc_html__( 'Post', 'franchise' ),
			 	)
		)
	);

	for ( $i=1; $i <= 3; $i++ ) { 
		
		// Services custom sub title setting
		$wp_customize->add_setting(
			'franchise_services_custom_sub_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'franchise_services_custom_sub_title_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Sub title ', 'franchise' ) . $i,
				'active_callback' => 'franchise_if_services_not_disabled',
				'input_attrs' => array(
				    'placeholder' => $default['franchise_services_custom_sub_title'],
				)
			)
		);

		// Services post setting
		$wp_customize->add_setting(
			'franchise_services_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_services_post_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Post ', 'franchise' ) . $i,
				'active_callback' => 'franchise_if_services_not_disabled',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);

		// Services separator setting
		$wp_customize->add_setting(
			'franchise_services_separator_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
			)
		);

		$wp_customize->add_control(
			new Franchise_Separator_Custom_Control( 
			$wp_customize,
			'franchise_services_separator_' . $i,
				array(
					'section'		=> 'franchise_services',
					'active_callback' => 'franchise_if_services_not_disabled',
					'type'			=> 'franchise-separator',
				)
			)
		);
	}

	/**
	 * Projects section
	 */
	// Projects section
	$wp_customize->add_section(
		'franchise_projects',
		array(
			'title' => esc_html__( 'Projects', 'franchise' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Projects enable settings
	$wp_customize->add_setting(
		'franchise_projects',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'post'
		)
	);

	$wp_customize->add_control(
		'franchise_projects',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Content type:', 'franchise' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise' ),
					'post' => esc_html__( 'Post', 'franchise' ),
			 	)
		)
	);

	// Projects title setting
	$wp_customize->add_setting(
		'franchise_projects_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_projects_title',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Title:', 'franchise' ),
			'active_callback' => 'franchise_if_projects_not_disabled',
			'input_attrs' => array(
			    'placeholder' => $default['franchise_projects_title'],
			)
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_projects_title', 
		array(
	        'selector'            => '#projects-section .section-title',
			'render_callback'     => 'franchise_projects_partial_title',
    	) 
    );

    // Projects sub title setting
	$wp_customize->add_setting(
		'franchise_projects_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_projects_sub_title',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Sub Title:', 'franchise' ),
			'active_callback' => 'franchise_if_projects_not_disabled',
			'input_attrs' => array(
			    'placeholder' => $default['franchise_projects_sub_title'],
			)
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_projects_sub_title', 
		array(
	        'selector'            => '#projects-section .section-subtitle',
			'render_callback'     => 'franchise_projects_partial_sub_title',
    	) 
    );

	for ( $i=1; $i <= 6; $i++ ) { 

		// Projects post setting
		$wp_customize->add_setting(
			'franchise_projects_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_projects_post_' . $i,
			array(
				'section'		=> 'franchise_projects',
				'label'			=> esc_html__( 'Post ', 'franchise' ) . $i,
				'active_callback' => 'franchise_if_projects_not_disabled',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);

	}

	/**
	 * Testimonial section
	 */
	// Testimonial section
	$wp_customize->add_section(
		'franchise_testimonial',
		array(
			'title' => esc_html__( 'Testimonial', 'franchise' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Testimonial enable settings
	$wp_customize->add_setting(
		'franchise_testimonial',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'post'
		)
	);

	$wp_customize->add_control(
		'franchise_testimonial',
		array(
			'section'		=> 'franchise_testimonial',
			'label'			=> esc_html__( 'Content type:', 'franchise' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise' ),
					'post' => esc_html__( 'Post', 'franchise' ),
			 	)
		)
	);

	for ( $i=1; $i <= 2; $i++ ) { 
		// Testimonial post setting
		$wp_customize->add_setting(
			'franchise_testimonial_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_testimonial_post_' . $i,
			array(
				'section'		=> 'franchise_testimonial',
				'label'			=> esc_html__( 'Post ', 'franchise' ) . $i,
				'active_callback' => 'franchise_if_testimonial_post',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);

		// Testimonial custom sub title setting
		$wp_customize->add_setting(
			'franchise_testimonial_custom_sub_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'franchise_testimonial_custom_sub_title_' . $i,
			array(
				'section'		=> 'franchise_testimonial',
				'label'			=> esc_html__( 'Sub title ', 'franchise' ) . $i,
				'active_callback' => 'franchise_if_testimonial_post',
				'input_attrs' => array(
				    'placeholder' => $default['franchise_testimonial_custom_sub_title'],
				)
			)
		);
	}

	/**
	 * Blog section section
	 */
	// Blog section section
	$wp_customize->add_section(
		'franchise_blog_section',
		array(
			'title' => esc_html__( 'Blog section', 'franchise' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Blog section enable settings
	$wp_customize->add_setting(
		'franchise_blog_section',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'post'
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Content type:', 'franchise' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise' ),
					'post' => esc_html__( 'Post', 'franchise' ),
			 	)
		)
	);

	// Blog section title setting
	$wp_customize->add_setting(
		'franchise_blog_section_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section_title',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Title:', 'franchise' ),
			'active_callback' => 'franchise_if_blog_section_post',
			'input_attrs' => array(
			    'placeholder' => $default['franchise_blog_section_title'],
			)
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_blog_section_title', 
		array(
	        'selector'            => '#latest-posts .section-title',
			'render_callback'     => 'franchise_blog_section_partial_title',
    	) 
    );

    // Blog section sub title setting
	$wp_customize->add_setting(
		'franchise_blog_section_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section_sub_title',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Sub Title:', 'franchise' ),
			'active_callback' => 'franchise_if_blog_section_post',
			'input_attrs' => array(
			    'placeholder' => $default['franchise_blog_section_sub_title'],
			)
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_blog_section_sub_title', 
		array(
	        'selector'            => '#latest-posts .section-subtitle',
			'render_callback'     => 'franchise_blog_section_partial_sub_title',
    	) 
    );

	for ( $i=1; $i <= 2; $i++ ) { 
		// Projects post setting
		$wp_customize->add_setting(
			'franchise_blog_section_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_blog_section_post_' . $i,
			array(
				'section'		=> 'franchise_blog_section',
				'label'			=> esc_html__( 'Post ', 'franchise' ) . $i,
				'active_callback' => 'franchise_if_blog_section_post',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);
	}

	/**
	 *
	 * General settings panel
	 * 
	 */
	// General settings panel
	$wp_customize->add_panel(
		'franchise_general_panel',
		array(
			'title' => esc_html__( 'Advanced Settings', 'franchise' ),
			'priority' => 107
		)
	);

	$wp_customize->get_section( 'colors' )->panel         = 'franchise_general_panel';
	
	// Header title color setting
	$wp_customize->add_setting(	
		'franchise_header_title_color',
		array(
			'sanitize_callback' => 'franchise_sanitize_hex_color',
			'default' => '#ff8737',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'franchise_header_title_color',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site title Color:', 'franchise' ),
			)
		)
	);

	// Header tagline color setting
	$wp_customize->add_setting(	
		'franchise_header_tagline',
		array(
			'sanitize_callback' => 'franchise_sanitize_hex_color',
			'default' => '#929292',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'franchise_header_tagline',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site tagline Color:', 'franchise' ),
			)
		)
	);

	$wp_customize->get_section( 'background_image' )->panel         = 'franchise_general_panel';
	$wp_customize->get_section( 'custom_css' )->panel         = 'franchise_general_panel';

	/**
	 * General settings
	 */
	// General settings
	$wp_customize->add_section(
		'franchise_general_section',
		array(
			'title' => esc_html__( 'General', 'franchise' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Backtop enable setting
	$wp_customize->add_setting(
		'franchise_back_to_top_enable',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_back_to_top_enable',
		array(
			'section'		=> 'franchise_general_section',
			'label'			=> esc_html__( 'Enable Scroll up.', 'franchise' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Blog/Archive section 
	 */
	// Blog/Archive section 
	$wp_customize->add_section(
		'franchise_archive_settings',
		array(
			'title' => esc_html__( 'Archive/Blog', 'franchise' ),
			'description' => esc_html__( 'Settings for archive pages including blog page too.', 'franchise' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Archive excerpt setting
	$wp_customize->add_setting(
		'franchise_archive_excerpt',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'franchise_archive_excerpt',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Excerpt more text:', 'franchise' ),
			'input_attrs' => array(
			    'placeholder' => esc_html__( 'View the post', 'franchise' ),
			)
		)
	);

	// Archive excerpt length setting
	$wp_customize->add_setting(
		'franchise_archive_excerpt_length',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
		)
	);

	$wp_customize->add_control(
		'franchise_archive_excerpt_length',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Excerpt more length:', 'franchise' ),
			'type'			=> 'number',
			'input_attrs'   => array( 'min' => 5, 'placeholder' => 40 ),
		)
	);

	// Pagination type setting
	$wp_customize->add_setting(
		'franchise_archive_pagination_type',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'numeric',
		)
	);

	$archive_pagination_description = '';
	$archive_pagination_choices = array( 
				'disable' => esc_html__( '--Disable--', 'franchise' ),
				'numeric' => esc_html__( 'Numeric', 'franchise' ),
				'older_newer' => esc_html__( 'Older / Newer', 'franchise' ),
			);
	if ( ! class_exists( 'JetPack' ) ) {
		$archive_pagination_description = sprintf( esc_html__( 'We recommend to install %1$sJetpack%2$s and enable %3$sInfinite Scroll%4$s feature for automatic loading of posts.', 'franchise' ), '<a target="_blank" href="http://wordpress.org/plugins/jetpack">', '</a>', '<b>', '</b>' );
	} else {
		$archive_pagination_choices['infinite_scroll'] = esc_html__( 'Infinite Load', 'franchise' );
	}
	$wp_customize->add_control(
		'franchise_archive_pagination_type',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Pagination type:', 'franchise' ),
			'description'			=>  $archive_pagination_description,
			'type'			=> 'select',
			'choices'		=> $archive_pagination_choices,
		)
	);

	/**
	 * Single setting section 
	 */
	// Single setting section 
	$wp_customize->add_section(
		'franchise_single_settings',
		array(
			'title' => esc_html__( 'Single Posts', 'franchise' ),
			'description' => esc_html__( 'Settings for all single posts.', 'franchise' ),
			'panel' => 'franchise_general_panel',
		)
	);
}
add_action( 'customize_register', 'franchise_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function franchise_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function franchise_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function franchise_customize_preview_js() {
	wp_enqueue_script( 'franchise-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'franchise_customize_preview_js' );

/**
 * Binds JS handlers for Customizer controls.
 */
function franchise_customize_control_js() {

	wp_enqueue_script( 'franchise-customize-control', get_theme_file_uri( '/assets/js/customize-control.js' ), array( 'jquery', 'customize-controls' ), '20151215', true );
	$franchise_localized_data = array( 
		'refresh_msg' => esc_html__( 'Refresh the page after Save and Publish.', 'franchise' ),
	);

	wp_localize_script( 'franchise-customize-control', 'franchise_localized_data', $franchise_localized_data );
}
add_action( 'customize_controls_enqueue_scripts', 'franchise_customize_control_js' );

/**
 *
 * Sanitization callbacks.
 * 
 */

/**
 * Checkbox sanitization callback example.
 * 
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function franchise_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}


/**
 * HEX Color sanitization callback example.
 *
 * - Sanitization: hex_color
 * - Control: text, WP_Customize_Color_Control
 *
 */
function franchise_sanitize_hex_color( $hex_color, $setting ) {
	// Sanitize $input as a hex value without the hash prefix.
	$hex_color = sanitize_hex_color( $hex_color );
	
	// If $input is a valid hex value, return it; otherwise, return the default.
	return ( ! is_null( $hex_color ) ? $hex_color : $setting->default );
}

/**
 * Image sanitization callback example.
 *
 * Checks the image's file extension and mime type against a whitelist. If they're allowed,
 * send back the filename, otherwise, return the setting default.
 *
 * - Sanitization: image file extension
 * - Control: text, WP_Customize_Image_Control
 */
function franchise_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon',
        'svg'          => 'image/svg+xml'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}

/**
 * Select sanitization callback example.
 *
 * - Sanitization: select
 * - Control: select, radio
 */
function franchise_sanitize_select( $input, $setting ) {
	
	// Ensure input is a slug.
	$input = sanitize_key( $input );
	
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Drop-down Pages sanitization callback example.
 *
 * - Sanitization: dropdown-pages
 * - Control: dropdown-pages
 * 
 */
function franchise_sanitize_dropdown_pages( $page_id, $setting ) {
	// Ensure $input is an absolute integer.
	$page_id = absint( $page_id );
	
	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/**
 * Number Range sanitization callback example.
 *
 * - Sanitization: number_range
 * - Control: number, tel
 * 
 */
function franchise_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

/**
 * HTML sanitization callback example.
 *
 * - Sanitization: html
 * - Control: text, textarea
 *
 * @param string $html HTML to sanitize.
 * @return string Sanitized HTML.
 */
function franchise_sanitize_html( $html ) {
	return wp_filter_post_kses( $html );
}

/**
 * Sortable section sanitization callback example.
 *
 * - Sanitization: sortable section
 * - Control: sortable
 *
 * @param string $input Value to be sanitized.
 * @return array Sanitized values as array.
 */
function franchise_sanitize_sort( $input ) {
	// Ensure $input is an array.
	if ( ! is_array( $input ) ){
		$input = explode( ',', $input );
	}

	$output = array_map( 'sanitize_text_field', $input );

	return $output;
}

/**
 *
 * Active callbacks.
 * 
 */

/**
 * Check if the about is enabled
 */
function franchise_if_about_enabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_about' )->value();
}

/**
 * Check if the projects is not disabled
 */
function franchise_if_projects_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_projects' )->value();
}

/**
 * Check if the services is not disabled
 */
function franchise_if_services_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_services' )->value();
}

/**
 * Check if the testimonial is post
 */
function franchise_if_testimonial_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_testimonial' )->value();
}

/**
 * Check if the slider is not disabled
 */
function franchise_if_slider_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_slider' )->value();
}

/**
 * Check if the blog section is post
 */
function franchise_if_blog_section_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_blog_section' )->value();
}

/**
 * Selective refresh.
 */

/**
 * Selective refresh for about sub title.
 */
function franchise_about_partial_sub_title() {
	return esc_html( get_theme_mod( 'franchise_about_sub_title' ) );
}

/**
 * Selective refresh for projects title.
 */
function franchise_projects_partial_title() {
	return esc_html( get_theme_mod( 'franchise_projects_title' ) );
}

/**
 * Selective refresh for projects btn text.
 */
function franchise_projects_partial_sub_title() {
	return esc_html( get_theme_mod( 'franchise_projects_sub_title' ) );
}

/**
 * Selective refresh for blog section title.
 */
function franchise_blog_section_partial_title() {
	return esc_html( get_theme_mod( 'franchise_blog_section_title' ) );
}

/**
 * Selective refresh for blog section text.
 */
function franchise_blog_section_partial_sub_title() {
	return esc_html( get_theme_mod( 'franchise_blog_section_sub_title' ) );
}

/**
 * Selective refresh for your latest posts title.
 */
function franchise_your_latest_posts_partial_title() {
	return esc_html( get_theme_mod( 'franchise_your_latest_posts_title' ) );
}